@@ -7,9 +7,9 @@ use warnings;
 
 use Carp;
 
-use base qw{ Exporter };
+use Exporter qw{ import };
 
-our $VERSION = '0.100';
+our $VERSION = '0.101';
 
 our @EXPORT_OK = qw{
     meta_merge
@@ -44,7 +44,7 @@ sub meta_merge {
 	resources	=> {
 	    bugtracker	=> {
                 web => 'https://rt.cpan.org/Public/Dist/Display.html?Name=Perl-Critic-Policy-Variables-ProhibitUnusedVarsStricter',
-                mailto  => 'wyant@cpan.org',
+##                mailto  => 'wyant@cpan.org',
             },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
@@ -156,7 +156,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2016 by Thomas R. Wyant, III
+Copyright (C) 2013-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
